==> tuia-advert-center-api-1.5.0-20180623.112104-34-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/WhiteApplyRelationDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.util.Date;

public class WhiteApplyRelationDto {
    private Long id;

    private Integer sourceType;

    private Long sourceId;

    private String sourceValue;

    private Long applyId;

    private String strategyTypes;

    private Date gmtCreate;

    private Date gmtModified;

    public String getStrategyTypes() {
        return strategyTypes;
    }

    public void setStrategyTypes(String strategyTypes) {
        this.strategyTypes = strategyTypes;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getSourceValue() {
        return sourceValue;
    }

    public void setSourceValue(String sourceValue) {
        this.sourceValue = sourceValue == null ? null : sourceValue.trim();
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-advert-center-api-1.5.9-20180715.070155-9-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/WhiteApplyRelationDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.math.BigDecimal;
import java.util.Date;

public class WhiteApplyRelationDto {
    private Long id;

    private Integer sourceType;

    private Long sourceId;

    private String sourceValue;

    private Long applyId;

    private String strategyTypes;

    private BigDecimal nearlyWeekCvr;

    private BigDecimal forecastCvr;

    private Date gmtCreate;

    private Date gmtModified;

    public BigDecimal getNearlyWeekCvr() {
        return nearlyWeekCvr;
    }

    public void setNearlyWeekCvr(BigDecimal nearlyWeekCvr) {
        this.nearlyWeekCvr = nearlyWeekCvr;
    }

    public BigDecimal getForecastCvr() {
        return forecastCvr;
    }

    public void setForecastCvr(BigDecimal forecastCvr) {
        this.forecastCvr = forecastCvr;
    }

    public String getStrategyTypes() {
        return strategyTypes;
    }

    public void setStrategyTypes(String strategyTypes) {
        this.strategyTypes = strategyTypes;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getSourceValue() {
        return sourceValue;
    }

    public void setSourceValue(String sourceValue) {
        this.sourceValue = sourceValue == null ? null : sourceValue.trim();
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
